import { publishReplay, refCount, tap } from 'rxjs/operators/index.js';

/**
 * Creates a function that memorizes the observable result of func.
 * If the Observable errors, the value will not be cached.
 *
 * @param resolver If resolver provided, it determines the cache key for storing the result based on
 * the first argument provided to the memorized function.
 */
function memoizeObservable(func, resolver) {
  const cache = new Map();
  return (parameters, force = false) => {
    const key = resolver(parameters);
    const hit = cache.get(key);
    if (!force && hit) {
      return hit;
    }
    const observable = func(parameters).pipe(publishReplay(), refCount(), tap({
      error: () => {
        cache.delete(key);
      }
    }));
    cache.set(key, observable);
    return observable;
  };
}

export { memoizeObservable };
//# sourceMappingURL=memorize-observable.js.map
